package test;

import main.ConfigureDriver;
import main.CsvBuilder;
import main.DomainGrabber;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.CsvFileSource;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.By;

import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.junit.jupiter.api.Assertions.fail;

public class TestLogin {
    private static final String domain = DomainGrabber.getDomain();
    private static final String LOGIN_PAGE = "https://" + domain + "/wp-login.php";
    private static final String USERNAME_BOX_ID = "user_login";
    private static final String PASSWORD_BOX_ID = "user_pass";
    private static final String LOGIN_BUTTON_ID = "wp-submit";
    private static final String EXPECTED_URL = "https://" + domain + "/wp-admin/";

    @BeforeAll
    public static void initReport() {
        CsvBuilder.createTestReportFile(); // Reuses the same report for consistency
    }

    @ParameterizedTest
    @CsvFileSource(resources = "/csv/built/all_login_credentials.csv", numLinesToSkip = 0)
    public void testLogin(String usernameText, String passwordText) {
        WebDriver driver = ConfigureDriver.configureDriver();
        driver.manage().window().maximize();
        driver.get(LOGIN_PAGE);

        try {
            WebElement username = driver.findElement(By.id(USERNAME_BOX_ID));
            WebElement password = driver.findElement(By.id(PASSWORD_BOX_ID));
            WebElement login = driver.findElement(By.id(LOGIN_BUTTON_ID));

            username.sendKeys(usernameText);
            System.out.println("Testing " + usernameText);
            password.sendKeys(passwordText);
            login.click();

            boolean loginSuccessful = driver.getCurrentUrl().startsWith(EXPECTED_URL);
            CsvBuilder.appendTestResult("N/A", usernameText, "Login", loginSuccessful ? "PASS" : "FAIL");
            assertTrue(loginSuccessful, "Login failed for user: " + usernameText);

        } catch (Exception e) {
            CsvBuilder.appendTestResult("N/A", usernameText, "Login", "FAIL - Exception: " + e.getMessage());
            fail("Exception during login test: " + e.getMessage());
        } finally {
            driver.quit();
        }
    }
}
